*
*
*
* Replication file SSQ-replication-PID.do
* Look Over There. Where? A Compositional Approach to the Modeling of Public Opinion on the Most Important Problem
* Authors: Steven Jokinsky, Christine Lipsmeyer, Andrew Philips, Laron Williams, Guy Whitten
* -------------------------------------------------------------------------
cd "/Users/aqpimac/Dropbox/Lipsmeyer_Philips_Whitten_Williams/SSQ Submission 2023/Final Version/Replication"
use "ssq-replicationdata-pid.dta", clear

* ------------------------------ RUN PROGRAMS AND GLOBALS ------------------------------
do "dynsimpieladderplotldv.ado"
do "multidynsimpieldv.ado"

* --------- program to select min aic ---------------
* (for maxlag = 8, after running est table, stats(aic))
cap prog drop minaic
prog define minaic, rclass
	mat aic = r(stats)
	forv i = 1/8 {
		if `i' == 1 {
			loc minaic = aic[1,`i']
			loc lag = `i'
		}
		else {
			if aic[1,`i'] < `minaic' {
				loc minaic = aic[1,`i']
				loc lag = `i'
			}
		}
	}
	di "Ideal lag selection is `lag', as determined via AIC (value of `minaic')"
	return local lag = "`lag'"
end
* -------------------------------------------------

global lreplotnoind "twoway rspike var_pie_ll_lr__dem var_pie_ul_lr__dem sort_pad1, horizontal lcolor(black) || rspike var_pie_ll_lr__rep var_pie_ul_lr__rep sort_pad2, horizontal lcolor(black) || scatter sort_pad1 mid_lr_dem, msymbol(T) mcolor("0 0 255") msize(medlarge) || scatter sort_pad2 mid_lr_rep, msymbol(S) mcolor("204 0 0") msize(medlarge) xline(0, lcolor(black) lstyle(solid)) yscale(axis(1) noline) xlabel(, grid glcolor(gs15)) plotregion(style(none)) legend(order(3 "Democrat" 4 "Republican") ) xtitle("Predicted Change from Baseline")  ylabel(1 "Crime" 2 "Social Welfare" 3 "Intl. Affairs" 4 "Culture" 5 "Other" 6 "Economic Issues", angle(45)) ysize(5) title("Long-Run")"

* Create list of DVs for each type of income:
global dvs1 "code11_1_perc_i_code1 code6_1_perc_i_code1 code14_1_perc_i_code1  code19_1_perc_i_code1 code21_1_perc_i_code1" // Democrats

global dvs3 "code11_3_perc_i_code1 code6_3_perc_i_code1 code14_3_perc_i_code1  code19_3_perc_i_code1 code21_3_perc_i_code1" // Republicans

* -------------------------------------------------------------------------



/* Here's the order of PID:
code1_3_perc    Republicans
code1_2_perc   Leaners/Independent
code1_1_perc Democrats

*/ 

tsset tsm

set seed 2330999

/* Here are the categories:
1=macroeconomy
11=crime
6= social welfare
14=international affairs
19=culture
21=other.
*/

gen fakeid = 1 // need to trick dynsimpiecstsldv into thinking we have csts data
xtset fakeid tsm


* Figure 2: ----------------------------------------
* showing Republicans and Democrats for macroeconomy
twoway line code1_3_perc_i tsm, lwidth(medthick) lpattern(dash) lcolor(cranberry) || line code1_1_perc_i tsm, lwidth(medthick) lpattern(solid) lcolor(midblue) legend(order(1 "Republican" 2 "Democrat") rows(1) position(0) bplacement(neast)) title("Economic Issues") xtitle("") ytitle("MIP (%)")
*graph export "EA-pid-macroecon.pdf", as(pdf) replace
* ----------------------------------------------------

* Figure 3: ----------------------------------------
* same as fig 2 but from 2008m1 to 2009m12
twoway line code1_3_perc_i tsm if counter >= 493 & counter < 517, lwidth(medthick) lpattern(dash) lcolor(cranberry) || line code1_1_perc_i tsm if counter >= 493 & counter < 517, lwidth(medthick) lpattern(solid) lcolor(midblue) legend(order(1 "Republican" 2 "Democrat") rows(1) ) title("Economic Issues") xtitle("") ytitle("MIP (%)")
*graph export "EA-pid-macroecon-2008m1-2009m12.pdf", as(pdf) replace
* ----------------------------------------------------

* Figure 4: ----------------------------------------
* A stable, all-constant expected value across types
* --------------------------------------------------------------------------
* here's dems
multidynsimpieldv lpost911 lgdp_growth nytmacrol1 licb_total linflation  nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) t(4) id(fakeid) shock(0) shockvar(lch_gasprice)  saving("dynsimpie_dem")
* heres rep
multidynsimpieldv lpost911 lgdp_growth nytmacrol1 licb_total linflation  nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs3) t(4) id(fakeid) shock(0) shockvar(lch_gasprice)  saving("dynsimpie_rep")

preserve
use "dynsimpie_dem", clear
foreach var of varlist var1_pie_ll_ - mid6 {
	rename `var' `var'_dem
}
joinby time using "dynsimpie_rep"
foreach var of varlist var1_pie_ll_ - mid6 {
	rename `var' `var'_rep
}
keep if time == 20 // we only need final predictions
* place the numbers at the end of each var to reshape long:
forv i = 1/6 {
	rename var`i'_pie_ll__dem var_pie_ll__dem`i'
	rename var`i'_pie_ul__dem  var_pie_ul__dem`i'
	rename mid`i'_dem mid_dem`i'
	rename var`i'_pie_ll__rep var_pie_ll__rep`i'
	rename var`i'_pie_ul__rep var_pie_ul__rep`i'
	rename mid`i'_rep mid_rep`i'
}
reshape long var_pie_ll__dem var_pie_ul__dem mid_dem var_pie_ll__rep var_pie_ul__rep mid_rep, i(time) j(count)
gen pad1 = count - .2
gen pad2 = count + .2
twoway rspike var_pie_ll__dem var_pie_ul__dem pad1, horizontal lcolor(black) || rspike var_pie_ll__rep var_pie_ul__rep pad2, horizontal lcolor(black) || scatter pad1 mid_dem, msymbol(T) mcolor("0 0 255") msize(medlarge) || scatter pad2 mid_rep, msymbol(S) mcolor("204 0 0") msize(medlarge) xline(0, lcolor(black) lstyle(solid)) yscale(axis(1) noline) xlabel(, grid glcolor(gs15)) plotregion(style(none)) legend(order(3 "Democrat" 4 "Republican") ) xtitle("Predicted Proportion")  ylabel(1 "Crime" 2 "Social Welfare" 3 "Intl. Affairs" 4 "Culture" 5 "Other" 6 "Economic Issues", angle(45)) ysize(5)
*graph export "pid-stablepredictions.pdf", as(pdf) replace
restore
* ----------------------------------------------------

* Figure 7: ----------------------------------------
* ------------------------ a +1SD shock to lunemployment ---------------------
su lunemployment
* here's democrats
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 licb_total nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(1.63) shockvar(lunemployment) saving("dynsimpie_dem")

* here's Republicans
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 licb_total nixon ford carter reagan hwbush clinton gwbush, dvs($dvs3) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(1.63) shockvar(lunemployment) saving("dynsimpie_rep")

* now combine all of them to make SR and LR plots across types:
preserve
use "dynsimpie_dem", clear
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_dem
}
joinby sort using "dynsimpie_rep"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_rep
}

gen sort_pad1 = sort - .2
gen sort_pad2 = sort + .2
$lreplotnoind
*graph export "pid-LR-unemployment.pdf", as(pdf) replace
restore

* ----------------------------------------------------

* Figure 8: ----------------------------------------
* ------------------------ a +1SD shock to licb_total ---------------------
su licb_total // so 1 SD ~ 0.35
* here's democrats
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.35) shockvar(licb_total) saving("dynsimpie_dem")

* here's Republicans
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs3) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.35) shockvar(licb_total) saving("dynsimpie_rep")
* now combine all of them to make SR and LR plots across types:
preserve
use "dynsimpie_dem", clear
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_dem
}
joinby sort using "dynsimpie_rep"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_rep
}

gen sort_pad1 = sort - .2
gen sort_pad2 = sort + .2
$lreplotnoind
*graph export "pid-LR-icb_total.pdf", as(pdf) replace
restore


* ------------------------ SI Figure A4: a +1SD shock to icb34_total ---------------------
su icb34_total // so 1 SD ~ .22
* here's democrats
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(.22) shockvar(licb34_total) saving("dynsimpie_dem")

* here's Republicans
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs3) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(.22) shockvar(licb34_total) saving("dynsimpie_rep")
* now combine all of them to make SR and LR plots across types:
preserve
use "dynsimpie_dem", clear
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_dem
}
joinby sort using "dynsimpie_rep"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_rep
}

gen sort_pad1 = sort - .2
gen sort_pad2 = sort + .2
$lreplotnoind
*graph export "pid-LR-icb34_total.pdf", as(pdf) replace
restore

* -------- SI Table A.1: Testing for parallel trends --------------------
* ARIMA models with auto-lag selection across each of our DVs in a SUR setup, include decade (and then presidential) dummies and test whether the decadal dummies differ between, e.g., republicans and democrats.

*3 =   Republicans
*1 =  Democrats

/* Here are the categories:
1=macroeconomy
11=crime
6= social welfare
14=international affairs
19=culture
21=other.
*/

* loop through each DV:
set more on
foreach dvnum in 1 11 6 14 19 21 {
	di ""
	di "--------------------------"
	qui sureg (code`dvnum'_1_perc_i l(1/8).code`dvnum'_1_perc_i dec*, nocon) (code`dvnum'_3_perc_i l(1/8).code`dvnum'_3_perc_i dec*, nocon)
	cap drop minobs
	qui gen minobs = e(sample)
	* now loop and report back min AIC, run model and test params:
	forv i = 1/8 {
		qui sureg (code`dvnum'_1_perc_i l(1/`i').code`dvnum'_1_perc_i dec*, nocon) ///
		(code`dvnum'_3_perc_i l(1/`i').code`dvnum'_3_perc_i dec*, nocon) if minobs == 1
		est store model`i'
	}
	qui est table model*, stats(aic)
	minaic
	qui sureg (code`dvnum'_1_perc_i l(1/`r(lag)').code`dvnum'_1_perc_i dec*, nocon) ///
	(code`dvnum'_3_perc_i l(1/`r(lag)').code`dvnum'_3_perc_i dec*, nocon)
	di "DV number is: `dvnum'"
	foreach i in 60 70 80 90 00 10 {
		di "Decade is `i', with p-value:"
		qui test _b[code`dvnum'_1_perc_i:dec`i'] = _b[code`dvnum'_3_perc_i:dec`i']
		loc roundp = round(r(p), 0.01)
		di "`roundp'"
		
	}
	more
}

* ---------------SI Table A.4----------------------
* now repeat, but also including presidential dummies and focusing on those
* loop through each DV:
set more on
foreach dvnum in 1 11 6 14 19 21 {
	di ""
	di "--------------------------"
	* next get min obs so that we're running all models on same data (587 obs so cubed root ~ 8):
	qui sureg (code`dvnum'_1_perc_i l(1/8).code`dvnum'_1_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_3_perc_i l(1/8).code`dvnum'_3_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon)
	cap drop minobs
	qui gen minobs = e(sample)
	* now loop and report back min AIC, run model and test params:
	forv i = 1/8 {
		qui sureg (code`dvnum'_1_perc_i l(1/`i').code`dvnum'_1_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
		(code`dvnum'_3_perc_i l(1/`i').code`dvnum'_3_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) if minobs == 1
		est store model`i'
	}
	qui est table model*, stats(aic)
	minaic
	qui sureg (code`dvnum'_1_perc_i l(1/`r(lag)').code`dvnum'_1_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_3_perc_i l(1/`r(lag)').code`dvnum'_3_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon)
	di "DV number is: `dvnum'"
	foreach var of varlist lbj nixon ford carter reagan hwbush clinton gwbush obama {
		di "Pres term is `var', with p-value:"
		qui test _b[code`dvnum'_1_perc_i:`var'] = _b[code`dvnum'_3_perc_i:`var']
		loc roundp = round(r(p), 0.01)
		di "`roundp'"
	}
	more
}
* Note that the Obama dummy drops out (probably b/c it's collinear w/ the 2010s decade dummy)




