*
*
*
* Replication file SSQ-replication-gender.do
* Look Over There. Where? A Compositional Approach to the Modeling of Public Opinion on the Most Important Problem
* Authors: Steven Jokinsky, Christine Lipsmeyer, Andrew Philips, Laron Williams, Guy Whitten
* -------------------------------------------------------------------------
cd "/Users/aqpimac/Dropbox/Lipsmeyer_Philips_Whitten_Williams/SSQ Submission 2023/Final Version/Replication"
use "ssq-replicationdata-gender.dta", clear

* ------------------------------ RUN PROGRAMS AND GLOBALS ------------------------------
do "dynsimpieladderplotldv.ado"
do "multidynsimpieldv.ado"

* --------- program to select min aic ---------------
* (for maxlag = 8, after running est table, stats(aic))
cap prog drop minaic
prog define minaic, rclass
	mat aic = r(stats)
	forv i = 1/8 {
		if `i' == 1 {
			loc minaic = aic[1,`i']
			loc lag = `i'
		}
		else {
			if aic[1,`i'] < `minaic' {
				loc minaic = aic[1,`i']
				loc lag = `i'
			}
		}
	}
	di "Ideal lag selection is `lag', as determined via AIC (value of `minaic')"
	return local lag = "`lag'"
end

global lreplot "twoway rspike var_pie_ll_lr__men var_pie_ul_lr__men sort_pad1, horizontal lcolor(black) || rspike var_pie_ll_lr__wom var_pie_ul_lr__wom sort_pad2, horizontal lcolor(black) || scatter sort_pad1 mid_lr_men, msymbol(T) mcolor("153 153 0") msize(medlarge) || scatter sort_pad2 mid_lr_wom, msymbol(S) mcolor("0 76 153") msize(medlarge) xline(0, lcolor(black) lstyle(solid)) yscale(axis(1) noline) xlabel(, grid glcolor(gs15)) plotregion(style(none)) legend(order(3 "Men" 4 "Women") ) xtitle("Predicted Change from Baseline")  ylabel(1 "Crime" 2 "Social Welfare" 3 "Intl. Affairs" 4 "Culture" 5 "Other" 6 "Economic Issues", angle(45)) ysize(5) title("Long-Run")"

* Create list of DVs for each type of income:
global dvs0 "code11_0_perc_i_code1 code6_0_perc_i_code1 code14_0_perc_i_code1  code19_0_perc_i_code1 code21_0_perc_i_code1" // Female

global dvs1 "code11_1_perc_i_code1 code6_1_perc_i_code1 code14_1_perc_i_code1  code19_1_perc_i_code1 code21_1_perc_i_code1" // Male
* -------------------------------------------------


set seed 200999
/* Here's the order of gender. "code1" stands for macroeconomy

code1_0_perc   Female
code1_1_perc   Male

*/ 
tsset tsm


/* Here are the categories:
1=macroeconomy
11=crime
6= social welfare
14=international affairs
19=culture
21=other.
*/

gen fakeid = 1 // need to trick dynsimpiecstsldv into thinking we have csts data
xtset fakeid tsm

* -----------------------------------------
* Figure 5
* a stable, all-constant expected value across types
* -----------------------------------------
* here's women
multidynsimpieldv lpost911 lgdp_growth nytmacrol1 licb_total linflation  nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs0) t(4) id(fakeid) shock(0) shockvar(lch_gasprice)  saving("dynsimpie_wom")
* and men
multidynsimpieldv lpost911 lgdp_growth nytmacrol1 licb_total linflation  nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) t(4) id(fakeid) shock(0) shockvar(lch_gasprice)  saving("dynsimpie_men")
preserve
use "dynsimpie_wom", clear
foreach var of varlist var1_pie_ll_ - mid6 {
	rename `var' `var'_wom
}
joinby time using "dynsimpie_men"
foreach var of varlist var1_pie_ll_ - mid6 {
	rename `var' `var'_men
}
keep if time == 20 // we only need final predictions
* now we need to place the numbers at the end of each var so we can reshape long:
forv i = 1/6 {
	rename var`i'_pie_ll__wom var_pie_ll__wom`i'
	rename var`i'_pie_ul__wom var_pie_ul__wom`i'
	rename mid`i'_wom mid_wom`i'
	rename var`i'_pie_ll__men var_pie_ll__men`i'
	rename var`i'_pie_ul__men var_pie_ul__men`i'
	rename mid`i'_men mid_men`i'
}
reshape long var_pie_ll__wom var_pie_ul__wom mid_wom var_pie_ll__men var_pie_ul__men mid_men, i(time) j(count)
gen pad1 = count - .2
gen pad2 = count + .2
twoway rspike var_pie_ll__men var_pie_ul__men pad1, horizontal lcolor(black) || rspike var_pie_ll__wom var_pie_ul__wom pad2, horizontal lcolor(black) || scatter pad1 mid_men, msymbol(T) mcolor("153 153 0") msize(medlarge) || scatter pad2 mid_wom, msymbol(S) mcolor("0 76 153") msize(medlarge) xline(0, lcolor(black) lstyle(solid)) yscale(axis(1) noline) xlabel(, grid glcolor(gs15)) plotregion(style(none)) legend(order(3 "Men" 4 "Women") ) xtitle("Predicted Proportion")  ylabel(1 "Crime" 2 "Social Welfare" 3 "Intl. Affairs" 4 "Culture" 5 "Other" 6 "Economic Issues", angle(45)) ysize(5)
*graph export "gender-stablepredictions.pdf", as(pdf) replace
restore
* --------------------------

* -----------------------------------------
* Figure 9
* ------------------------ a +1SD shock to lunemployment ---------------------
su lunemployment
* here's women
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 licb_total nixon ford carter reagan hwbush clinton gwbush, dvs($dvs0) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(1.63) shockvar(lunemployment) saving("dynsimpie_wom")

* here's men
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 licb_total nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(1.63) shockvar(lunemployment) saving("dynsimpie_men")

* now combine all of them to make LR plots across types:
preserve
use "dynsimpie_wom", clear
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_wom
}
joinby sort using "dynsimpie_men"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_men
}

gen sort_pad1 = sort - .2
gen sort_pad2 = sort + .2
* for LR only:
$lreplot
*graph export "gender-LR-unemployment.pdf", as(pdf) replace
restore
* -----------------------------------------


* -----------------------------------------
* Figure 10
* Long-Run Change from Baseline Proportions across Gender in Response to Interstate Crises
* -----------------------------------------
su licb_total // so 1 SD ~ 0.35
* here's women
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs0) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.35) shockvar(licb_total) saving("dynsimpie_wom")

* here's men
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.35) shockvar(licb_total) saving("dynsimpie_men")

* now combine all of them to make SR and LR plots across types:
preserve
use "dynsimpie_wom", clear
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_wom
}
joinby sort using "dynsimpie_men"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_men
}

gen sort_pad1 = sort - .2
gen sort_pad2 = sort + .2
* for LR only:
$lreplot
*graph export "gender-LR-icb_total.pdf", as(pdf) replace
restore
* -----------------------------------------


* -----------------------------------------
*		SI Figure A5: a +1SD shock to icb34_total
* -----------------------------------------
su icb34_total // so 1 SD ~ .22
* here's women
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs0) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.22) shockvar(licb34_total) saving("dynsimpie_wom")

* here's men
dynsimpieladderplotldv lpost911 lch_gasprice nytmacrol1 linflation lgdp_growth nytlawcrimel1 nytintlaffl1 lunemployment nixon ford carter reagan hwbush clinton gwbush, dvs($dvs1) range(100) endtime(100) basetime(80) time(84) id(fakeid) shock(0.22) shockvar(licb34_total) saving("dynsimpie_men")

* now combine all of them to make SR and LR plots across types:
preserve
use "dynsimpie_wom", clear
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_wom
}
joinby sort using "dynsimpie_men"
foreach var of varlist var_pie_ll_sr_ var_pie_ul_sr_ var_pie_ll_lr_ var_pie_ul_lr_ mid_sr mid_lr {
	rename `var' `var'_men
}

gen sort_pad1 = sort - .2
gen sort_pad2 = sort + .2
* for LR only:
$lreplot
*graph export "gender-LR-icb34_total.pdf", as(pdf) replace
restore


* -------- SI Table A.2: testing for parallel trends -----------------------
* ARIMA models with auto-lag selection across each of our DVs in a SUR setup, include decade (and then presidential) dummies and test whether the decadal dummies differ between, e.g., republicans and democrats. 
* Here are the codes: 0 == female, e.g., code1_0_perc. 1 == male, e.g., code1_1_perc.

* loop through each DV:
set more on
foreach dvnum in 1 11 6 14 19 21 {
	di ""
	di "--------------------------"
	* next get min obs so that we're running all models on same data (587 obs so cubed root ~ 8):
	qui sureg (code`dvnum'_1_perc_i l(1/8).code`dvnum'_1_perc_i dec*, nocon) (code`dvnum'_0_perc_i l(1/8).code`dvnum'_0_perc_i dec*, nocon)
	cap drop minobs
	qui gen minobs = e(sample)
	* now loop and report back min AIC, run model and test params:
	forv i = 1/8 {
		qui sureg (code`dvnum'_1_perc_i l(1/`i').code`dvnum'_1_perc_i dec*, nocon) ///
		(code`dvnum'_0_perc_i l(1/`i').code`dvnum'_0_perc_i dec*, nocon) if minobs == 1
		est store model`i'
	}
	qui est table model*, stats(aic)
	minaic
	qui sureg (code`dvnum'_1_perc_i l(1/`r(lag)').code`dvnum'_1_perc_i dec*, nocon) ///
	(code`dvnum'_0_perc_i l(1/`r(lag)').code`dvnum'_0_perc_i dec*, nocon)
	di "DV number is: `dvnum'"
	foreach i in 60 70 80 90 00 10 {
		di "Decade is `i', with p-value:"
		qui test _b[code`dvnum'_1_perc_i:dec`i'] = _b[code`dvnum'_0_perc_i:dec`i']
		loc roundp = round(r(p), 0.01)
		di "`roundp'"
		
	}
	more
}


* ------------------- SI Table A.5  ---------------------------------------
* now repeat, but also including presidential dummies and focusing on those
* loop through each DV:
set more on
foreach dvnum in 1 11 6 14 19 21 {
	di ""
	di "--------------------------"
	qui sureg (code`dvnum'_1_perc_i l(1/8).code`dvnum'_1_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_0_perc_i l(1/8).code`dvnum'_0_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon)
	cap drop minobs
	qui gen minobs = e(sample)
	* now loop and report back min AIC, run model and test params:
	forv i = 1/8 {
		qui sureg (code`dvnum'_1_perc_i l(1/`i').code`dvnum'_1_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
		(code`dvnum'_0_perc_i l(1/`i').code`dvnum'_0_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) if minobs == 1
		est store model`i'
	}
	qui est table model*, stats(aic)
	minaic
	qui sureg (code`dvnum'_1_perc_i l(1/`r(lag)').code`dvnum'_1_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon) ///
	(code`dvnum'_0_perc_i l(1/`r(lag)').code`dvnum'_0_perc_i dec* lbj nixon ford carter reagan hwbush clinton gwbush obama, nocon)
	di "DV number is: `dvnum'"
	foreach var of varlist lbj nixon ford carter reagan hwbush clinton gwbush obama {
		di "Pres term is `var', with p-value:"
		qui test _b[code`dvnum'_1_perc_i:`var'] = _b[code`dvnum'_0_perc_i:`var']
		loc roundp = round(r(p), 0.01)
		di "`roundp'"
	}
	more
}
* Note that the Obama dummy drops out (probably b/c it's collinear w/ the 2010s decade dummy)

* --------------------------------------------------------------------------
 




